/*
  Multi Sensor Receiver Reference Design

  This code provides a reference design for the Radio Bridge
  Particle gateway to receive sensor inputs from the SubGig, 345MHz,
  and 319MHz BridgeBee modules.

  (c) 2017 Radio Bridge Inc. and its subsidiaries.
*/

#include "application.h"
#include "leds.h"
#include "timers.h"

// timers for flashing the LED when a sensor event comes in
extern uint8_t led1_timer;
extern uint8_t led2_timer;
extern uint8_t led3_timer;

// timer flags for flashing the LEDs when a sensor event comes in
extern bool led1_timer_running;
extern bool led2_timer_running;
extern bool led3_timer_running;

// initialize the LEDs
void init_leds(void)
{
  // LEDs lines are outputs
  pinMode(LED1, OUTPUT);
  pinMode(LED2, OUTPUT);
  pinMode(LED3, OUTPUT);

  // LEDs are off by default
  digitalWrite(LED1, HIGH);
  digitalWrite(LED2, HIGH);
  digitalWrite(LED3, HIGH);
}

// turn an LED on by driving output low
void led_on(uint8_t led_num)
{
  digitalWrite(led_num, LOW);
}

// turn an LED off by driving output high
void led_off(uint8_t led_num)
{
  digitalWrite(led_num, HIGH);
}

// to start the LED flash, turn it on and start the timer
void start_led_flash(uint8_t led_num)
{
  // turn the LED on before starting timer
	led_on(led_num);

  // if the LED was turned on, then reset and start timer
  if(led_num == LED1)
  {
    led1_timer = 0;
    led1_timer_running = true;
  }

  if(led_num == LED2)
  {
    led2_timer = 0;
    led2_timer_running = true;
  }

  if(led_num == LED3)
  {
    led3_timer = 0;
    led3_timer_running = true;
  }
}
