/*
  Multi Sensor Receiver Reference Design

  This code provides a reference design for the Radio Bridge
  Particle gateway to receive sensor inputs from the SubGig, 345MHz,
  and 319MHz BridgeBee modules.

  (c) 2017 Radio Bridge Inc. and its subsidiaries.
*/

#include "application.h"


// allow up to 64 different sensors to report
#define MAX_SENSORS 64

// reserve 0xff for an invalid sensor index when not found
#define INVALID_SENSOR_INDEX 0xff

uint8_t process_message_subgig(void);
uint8_t process_message_345(void);
uint8_t process_message_319(void);

uint8_t find_sensor_index(uint32_t sensor_id);
uint8_t find_next_available_sensor_index();
uint8_t add_sensor(uint32_t sensor_id);
void init_sensor_list(void);


// generic data structure which holds sensor event data
// note that not all fields are used by every type of sensor
struct SENSOR_DATA
{
	// signal strength
	uint8_t rssi		:8;

	// unique ID of sensor
	uint32_t sensor_id	:32;

	// allows for multiple inputs for a sensor
	uint8_t input5      :1;
	uint8_t input4      :1;
	uint8_t input3      :1;
	uint8_t input2      :1;
	uint8_t input1      :1;
	uint8_t tamper      :1;

	// can be used to flag a sensor event that arrived out of sequence
	uint8_t out_of_order    :1;

	// true if the battery is low
	uint8_t low_batt    :1;
};
