/*
  Multi Sensor Receiver Reference Design

  This code provides a reference design for the Radio Bridge
  Particle gateway to receive sensor inputs from the SubGig, 345MHz,
  and 319MHz BridgeBee modules.

  (c) 2017 Radio Bridge Inc. and its subsidiaries.
*/

/*

This file has been modified by Radio Bridge Inc, original code provided
as shown in copyright below

*/


/******************************************************************
*  EasyTransfer Arduino Library
*		details and example sketch:
*			http://www.billporter.info/easytransfer-arduino-library/
*
*		Brought to you by:
*              Bill Porter
*              www.billporter.info
*
*		See Readme for other info and version history
*
*
*This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or(at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
<http://www.gnu.org/licenses/>
*
*This work is licensed under the Creative Commons Attribution-ShareAlike 3.0 Unported License.
*To view a copy of this license, visit http://creativecommons.org/licenses/by-sa/3.0/ or
*send a letter to Creative Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.
******************************************************************/

#include "application.h"
#include "serial-comm.h"

#include "Serial4/Serial4.h"
#include "Serial5/Serial5.h"

//create serial comm objects
SerialTransfer Serial_Transmit1, Serial_Receive1;
SerialTransfer Serial_Transmit2, Serial_Receive2;
SerialTransfer Serial_Transmit3, Serial_Receive3;


// transmit and receive buffers for serial commm
uint8_t rx_data1[MAX_PACKET_SIZE];
uint8_t tx_data1[MAX_PACKET_SIZE];

uint8_t rx_data2[MAX_PACKET_SIZE];
uint8_t tx_data2[MAX_PACKET_SIZE];

uint8_t rx_data3[MAX_PACKET_SIZE];
uint8_t tx_data3[MAX_PACKET_SIZE];


void init_serial(void)
{
  // for debug serial monitor
  Serial.begin(9600);

  // Serial ports for BridgeBee devices
  Serial1.begin(9600);
  Serial4.begin(9600);
  Serial5.begin(9600);

  // start the serial port for BridgeBee socket 1
  Serial_Transmit1.begin(tx_data1, (char)MAX_PACKET_SIZE, &Serial1);
  Serial_Receive1.begin(rx_data1, (char)MAX_PACKET_SIZE, &Serial1);

  // start the serial port for BridgeBee socket 2
  Serial_Transmit2.begin(tx_data2, (char)MAX_PACKET_SIZE, &Serial4);
  Serial_Receive2.begin(rx_data2, (char)MAX_PACKET_SIZE, &Serial4);

  // start the serial port for BridgeBee socket 3
  Serial_Transmit3.begin(tx_data3, (char)MAX_PACKET_SIZE, &Serial5);
  Serial_Receive3.begin(rx_data3, (char)MAX_PACKET_SIZE, &Serial5);
}


//Captures address and size of struct
void SerialTransfer::begin(uint8_t * ptr, uint8_t length, Stream *theStream)
{
	address = ptr;
	size = length;
	_stream = theStream;

	//dynamic creation of rx parsing buffer in RAM
	rx_buffer = (uint8_t*) malloc(size+1);
}

// Transmits tx buffer
void SerialTransfer::sendData(uint8_t tx_length)
{

	for(uint16_t i = 0; i<tx_length; i++)
	{
		_stream->write(*(address+i));
	}

}

// capture serial data from the BridgeBee devices
boolean SerialTransfer::receiveData()
{

    // first check overflow
    if(rx_array_inx >= MAX_PACKET_SIZE)
    {
        rx_array_inx = 0;
        return false;
    }


    // sync with "APP " prefix or "SEN " prefix
    if(_stream->available())
    {
        rx_buffer[rx_array_inx++] = _stream->read();

        // Look for APP prefix
        if(rx_buffer[0] == 'A')
        {

            if((rx_array_inx > 1) && (rx_buffer[1] != 'P'))
            {
                rx_array_inx = 0;
                return false;
            }

            if((rx_array_inx > 2) && (rx_buffer[2] != 'P'))
            {
                rx_array_inx = 0;
                return false;
            }

            if((rx_array_inx > 3) && (rx_buffer[3] != ' '))
            {
                rx_array_inx = 0;
                return false;
            }

        }
        // Look for SEN prefix
        else if(rx_buffer[0] == 'S')
        {

            if((rx_array_inx > 1) && (rx_buffer[1] != 'E'))
            {
                rx_array_inx = 0;
                return false;
            }

            if((rx_array_inx > 2) && (rx_buffer[2] != 'N'))
            {
                rx_array_inx = 0;
                return false;
            }

            if((rx_array_inx > 3) && (rx_buffer[3] != ' '))
            {
                rx_array_inx = 0;
                return false;
            }

        }
        else
        {
            rx_array_inx = 0;
            return false;
        }


    	// find message end at carriage return
    	if((rx_array_inx > 4) && (rx_buffer[rx_array_inx-1] == '\n'))
    	{
    	    memcpy(address,rx_buffer,size);
    	    rx_array_inx = 0;
    	    return true;
    	}
    }

	return false;
}
