/*
  Multi Sensor Receiver Reference Design

  This code provides a reference design for the Radio Bridge
  Particle gateway to receive sensor inputs from the SubGig, 345MHz,
  and 319MHz BridgeBee modules.

  (c) 2017 Radio Bridge Inc. and its subsidiaries.
*/

/*

This file has been modified by Radio Bridge Inc, original code provided
as shown in timers.h

*/


#include "application.h"
#include "application.h"
#include "timers.h"
#include "leds.h"

// timer interrupt ever 100ms
SparkCorePolledTimer updateTimer(100);

// incremented every time a timer event occurs
uint8_t timer_ticks = 0;

// timers for flashing the LEDs when sensor events arrive
uint8_t led1_timer = 0;
uint8_t led2_timer = 0;
uint8_t led3_timer = 0;

bool led1_timer_running = false;
bool led2_timer_running = false;
bool led3_timer_running = false;

// initialize timers
void init_timers(void)
{
    // create 100ms timer callback
	updateTimer.SetCallback(timer_100ms_callback);
}

// update timers
void update_timers(void)
{
    updateTimer.Update();
}


// free running 100ms timer callback
void timer_100ms_callback(void)
{
	// increment to indicate a timer event occurred.
	// Timer updates happen from main loop
	timer_ticks++;

}

// if there was a timer tick then check timers
void check_timers(void)
{
	// non-zero timer ticks means 100ms has passed and timers need to be updated
	if(timer_ticks)
	{
		timer_ticks--;

		// LED1 flash timer
		if(led1_timer_running)
		{
			led1_timer++;

			// if LED timer expired, then time to turn the LED off and stop timer
			if(led1_timer > LED1_TIMEOUT)
			{
				led1_timer_running = false;

				led_off(LED1);
			}
		}

		// LED2 flash timer
		if(led2_timer_running)
		{
			led2_timer++;

			// if LED timer expired, then time to turn the LED off and stop timer
			if(led2_timer > LED2_TIMEOUT)
			{
				led2_timer_running = false;

				led_off(LED2);
			}
		}

		// LED3 flash timer
		if(led3_timer_running)
		{
			led3_timer++;

			// if LED timer expired, then time to turn the LED off and stop timer
			if(led3_timer > LED3_TIMEOUT)
			{
				led3_timer_running = false;

				led_off(LED3);
			}
		}

	}
}




SparkCorePolledTimer::SparkCorePolledTimer(unsigned long timeoutMS){
    Reset();
    SetTimeout(timeoutMS);
    callback=NULL;
}

void SparkCorePolledTimer::SetTimeout(unsigned long timeoutMS){
    intervalMS=timeoutMS;
}

void SparkCorePolledTimer::Reset(void){
    timeMark=millis();
}

int SparkCorePolledTimer::HasElapsed(){
    unsigned long timeCurrent;
    unsigned long timeElapsed;
    int result=false;

    timeCurrent=millis();
    timeElapsed=timeCurrent-timeMark;


    if(timeElapsed>=intervalMS) {
        Reset();
        result=true;
    }
    return(result);
}

void SparkCorePolledTimer::Update(void){
    if (callback!=NULL) {
        if(HasElapsed()) {
            callback();
        }
    }
}

void SparkCorePolledTimer::SetCallback(void (*callbackFunction)(void)){
    callback=callbackFunction;
}
