/*
  Multi Sensor Receiver Reference Design

  This code provides a reference design for the Radio Bridge
  Particle gateway to receive sensor inputs from the SubGig, 345MHz,
  and 319MHz BridgeBee modules.

  (c) 2017 Radio Bridge Inc. and its subsidiaries.
*/

/*

This file has been modified by Radio Bridge Inc, original code provided
as shown in version history below

*/

#ifndef timers_h
#define timers_h

#include "application.h"

// timeout in units of 100ms
#define LED1_TIMEOUT 2
#define LED2_TIMEOUT 2
#define LED3_TIMEOUT 2

void timer_100ms_callback(void);
void init_timers(void);
void update_timers(void);
void check_timers(void);



//  **************************************************************
//  SparkCorePolledTimer.h
//  Simple Timer Library for the Spark Core. Lets you do time based events.
//
//  David Fowler 11/16/2014
//  Version 0.2
//  Converted into a Spark core library
//
//  David Fowler 09/07/2010
//  Version 0.2
//  Converted into an Arudino library and renamed to PolledTimer
//
//  David Fowler 11/18/09
//  Version 0.1
//  Eample Usage
//  SparkCorePolledTimer updateTimer(1000);  //Create a timer object and set it's timeout in milliseconds
//  void OnTimer(void);   //Prototype for timer callback method
//
//  setup(){  //Standard setup function...
//    updateTimer.SetCallback(OnTimer);  //Tell the time about the handler function.
//  }
//
//  loop(){  //Standard loop function...
//    updateTimer.Update();  //Must call this often in your loop. It will call the
//                           //handler method automatically when it's time too
//  }
//
//  void OnTimer(void) {  //Handler for the timer, will be called automatically
//     //do your time based stuff here...
//  }
//  **************************************************************



#define TIMECTL_INIT      0

class SparkCorePolledTimer {
  private:
    unsigned long timeMark;
	unsigned long intervalMS;
	void (*callback)(void);
  public:
    SparkCorePolledTimer(unsigned long timeoutMS);
	void SetTimeout(unsigned long timeoutMS);
	void Reset(void);
	int HasElapsed();
	void Update();
	void SetCallback(void (*callbackFunction)(void));
};

#endif
