/*
  Multi Sensor Receiver Reference Design

  This code provides a reference design for the Radio Bridge
  Particle gateway to receive sensor inputs from the SubGig, 345MHz,
  and 319MHz BridgeBee modules.

  (c) 2017 Radio Bridge Inc. and its subsidiaries.
*/

#include "application.h"
#include "message-processing.h"
#include "web-comm.h"
#include "string.h"

// data structure to hold sensor states
extern SENSOR_DATA sensor_data[MAX_SENSORS];

// string to be published to the server variable "sensors"
String sensors_publish;


// register the variables to be published to the server
void register_publish_variables(void)
{
    sensors_publish = "";
    Particle.variable("sensors", sensors_publish);
}

// publish the sensor data to the web app
void publish_sensor_data(uint8_t sensor_index)
{
    // used to identify new packets at the web app
    static uint8_t packet_count = 0;

    // used for constructing json packet with all sensor values
    char _json[256];

    // assign a unique sequence number to each post to Particle cloud so an app
    // can verify it has not missed any posts and that they are in the correct sequence
    packet_count++;

    // we need to publish all sensor data at once to ensure they aren't read out of order
    snprintf(_json, sizeof(_json), "{\"a\":\"%ld\",\"b\":\"%ld\",\"c\":\"%d\",\"d\":\"%d\",\"e\":\"%d\",\"f\":\"%d\",\"g\":\"%d\",\"h\":\"%d\"}",
        sensor_data[sensor_index].rssi, sensor_data[sensor_index].sensor_id, sensor_data[sensor_index].out_of_order, sensor_data[sensor_index].low_batt, sensor_data[sensor_index].input1, sensor_data[sensor_index].tamper, packet_count, 0);

    sensors_publish = String(_json);

    // publish sensor data to Particle cloud
    Particle.publish("sensors", sensors_publish);

}
